Document: solfege-doc-nb
Title: GNU Solfege Help (Norwegian)
Author: Tom Cato Amundsen
Abstract: Manual of the GNU solfege software.
Section: Education

Format: HTML
Index: /usr/share/doc/solfege/help/nb/index.html
Files: /usr/share/doc/solfege/help/nb/*.html
